<!--
    =====================================
    generator=datazen
    version=3.2.3
    hash=b723f07425b36d6448cc6d3d4521bbb2
    =====================================
-->

# svgen ([0.9.5](https://pypi.org/project/svgen/))

[![python](https://img.shields.io/pypi/pyversions/svgen.svg)](https://pypi.org/project/svgen/)
![Build Status](https://github.com/libre-embedded/svgen/workflows/Python%20Package/badge.svg)
[![codecov](https://codecov.io/gh/libre-embedded/svgen/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/libre-embedded/svgen)
![PyPI - Status](https://img.shields.io/pypi/status/svgen)
![Dependents (via libraries.io)](https://img.shields.io/librariesio/dependents/pypi/svgen)

*A tool for working with scalable vector graphics.*

Consider [sponsoring development](https://github.com/sponsors/libre-embedded).

([interface documentation](https://libre-embedded.github.io/python/svgen))

## Python Version Support

This package is tested with the following Python minor versions:

* [`python3.13`](https://docs.python.org/3.13/)
* [`python3.14`](https://docs.python.org/3.14/)

## Platform Support

This package is tested on the following platforms:

* `ubuntu-latest`
* `macos-latest`
* `windows-latest`

# Introduction

This utility provides a means to work on graphics with a programmatic workflow.

# Command-line Options

```
$ ./venv3.14/bin/svgen -h

usage: svgen [-h] [--version] [-v] [-q] [--curses] [--no-uvloop] [-C DIR]
             [-c CONFIG] [--height HEIGHT] [--width WIDTH] [--images]
             [-o OUTPUT]
             [scripts ...]

A tool for working with scalable vector graphics.

positional arguments:
  scripts              scripts to run for composing the SVG document (in
                       order)

options:
  -h, --help           show this help message and exit
  --version            show program's version number and exit
  -v, --verbose        set to increase logging verbosity
  -q, --quiet          set to reduce output
  --curses             whether or not to use curses.wrapper when starting
  --no-uvloop          whether or not to disable uvloop as event loop driver
  -C, --dir DIR        execute from a specific directory
  -c, --config CONFIG  top-level configuration to load (default: 'svgen.json')
  --height HEIGHT      height of the document, if not specified by
                       configuration (default: 100)
  --width WIDTH        width of the document, if not specified by
                       configuration (default: 100)
  --images             generate output images
  -o, --output OUTPUT  file to write SVG output (default: 'svgen.svg')

```

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`svgen`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![svgen's Dependency Graph](im/pydeps.svg)
